import * as types from "./actionTypes";
import api from "./api";
import { sendHttpRequest } from "../../redux/actions/httpActions";

export function summonWizard() {
  return { type: types.SUMMON_WIZARD };
}

export function dismissBot() {
  return { type: types.DISMISS_BOT };
}

export function loadBotSession(botName, userKey) {
  return async function(dispatch, getState) {
    try {
      dispatch({ type: types.INITIALIZE_BOT_SESSION_STARTED });
      const { frontendSession } = getState();
      const externalId = frontendSession.sessionId;
      const clientApplication = frontendSession.applicationCode;
      const data = await dispatch(
        sendHttpRequest(
          api.getBotSession(botName, externalId, clientApplication, userKey)
        )
      );
      dispatch({
        type: types.INITIALIZE_BOT_SESSION_SUCCESS,
        payload: data
      });
    } catch (error) {
      throw error;
    }
  };
}

export function initializeChat(sessionId) {
  return async function(dispatch) {
    try {
      dispatch({ type: types.INITIALIZE_BOT_CHAT_STARTED });
      const data = await dispatch(
        sendHttpRequest(api.initializeChat(sessionId))
      );
      dispatch({
        type: types.INITIALIZE_BOT_CHAT_SUCCESS,
        payload: data
      });
    } catch (error) {
      throw error;
    }
  };
}

export function saveMessage(
  chatId,
  messageSourceId,
  messageDate,
  messageContent
) {
  return async function(dispatch, getState) {
    try {
      const event = await dispatch(
        sendHttpRequest(
          api.saveMessage(chatId, messageSourceId, messageDate, messageContent)
        )
      );
      dispatch({ type: types.SAVE_BOT_MESSAGE_SUCCESS, payload: event });
      return event;
    } catch (error) {
      throw error;
    }
  };
}
